==> ICA-1.5.tar.gz: ICA-1.5/src/MSI/Gen2Spec/menubar.c <==
/*
   Owner:       Copyright 1992 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      $RCSfile: menubar.c,v $
   Purpose:     The menubar choices plus callbacks.

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    $Revision: 1.8 $
   Date:        $Date: 92/05/29 16:20:30 $

   HISTORY
   $Log:	menubar.c,v $
 * Revision 1.8  92/05/29  16:20:30  boyd
 * Changes to improve resizing, consisting mostly of replacing Form widgets with
 * Group, Table, and Viewform.
 * 
 * 
 * Revision 1.7  92/03/18  16:08:42  ware
 * *** empty log message ***
 * 
 * Revision 1.6  92/03/16  12:20:31  ware
 * Merging cso and OSU versions.  Changes for titles.
 * 
 * Revision 1.5  1992/03/10  21:46:06  cso
 * Had to redo this b/c cvs lost it during commit.
 *
 * Revision 1.3  1992/02/21  23:02:39  cso
 * Removed spec2gen related routines
 *
 * Revision 1.2  1992/02/18  18:27:01  cso
 * Restructured the interface for the opposite xlation direction
 *
 * Revision 1.1  1992/02/06  05:33:52  cso
 * Initial revision
 *
 * Revision 1.2  1992/01/28  17:13:01  cso
 * Put border around menubar
 *
 * Revision 1.1  1992/01/08  19:55:30  cso
 * Initial revision
 *

   Functions Index:
   AVAIL   NAME DEPENDS ON INTERNALLY      EXTERNALLY
   -----   ----            ----------      ----------

*/

/* #INCLUDES */

#include "widgets.h"
#include "Xica/help.h"
#include "types.h"
#include "defs.h"

#include "interface.h"
#include "menucalls.h"



/*
   FUNCTION: 		CreateFileMenu

   Synopsis: 
       Create the file options.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/


static void
CreateFileMenu(parent)

Widget
   parent;  /* The parent of this list of menu options */

{
   Arg
      args[MAXARGS]; /* List of arguments */
   int
      cnt;      /* Number of arguments */
   Widget
      loadsel,  /* Load  option widget */
      newsel,   /* New   option widget */
      quitsel,  /* Quit  option widget */
      resetsel, /* Reset option widget */
      savesel;  /* Save  option widget */
   
   /*
    * Offer RESET first, a line to separate, LOAD and SAVE,
    * another line separator, and lastly QUIT
    */
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Reset    "); cnt++;
   resetsel = XtCreateManagedWidget("resetsel", smeBSBObjectClass,
				    parent, args, cnt);
   XtAddCallback(resetsel, XtNcallback, Reset, NULL);
   
   cnt = 0;
   XtSetArg(args[cnt], XtNlineWidth, 3); cnt++;
   (void) XtCreateManagedWidget("linesep", smeLineObjectClass,
				parent, args, cnt);
   
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "New      "); cnt++;
   newsel = XtCreateManagedWidget("newsel", smeBSBObjectClass,
				  parent, args, cnt);
   XtAddCallback(newsel, XtNcallback, FileLoad, True);

   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Edit     "); cnt++;
   loadsel = XtCreateManagedWidget("loadsel", smeBSBObjectClass,
				   parent, args, cnt);
   XtAddCallback(loadsel, XtNcallback, FileLoad, False);

   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Save     "); cnt++;
   savesel = XtCreateManagedWidget("savesel", smeBSBObjectClass,
				   parent, args, cnt);
   XtAddCallback(savesel, XtNcallback, FileSave, NULL);

   cnt = 0;
   XtSetArg(args[cnt], XtNlineWidth, 3); cnt++;
   (void) XtCreateManagedWidget("linesep", smeLineObjectClass,
				parent, args, cnt);
   
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Quit     "); cnt++;
   quitsel = XtCreateManagedWidget("quitsel", smeBSBObjectClass,
				   parent, args, cnt);
   XtAddCallback(quitsel, XtNcallback, Quit, NULL);

   return;
}



/*
   FUNCTION: 		CreateCodeMenu

   Synopsis: 
       The menu dealing with making and running.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/


static void
CreateCodeMenu(parent)

Widget
   parent;  /* The parent of this list of menu options */

{
   Arg
      args[MAXARGS];
   int
      cnt;
   Widget
      makesel,
      runsel,
      shell;
   
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Make"); cnt++;
   makesel = XtCreateManagedWidget("makesel", smeBSBObjectClass,
				 parent, args, cnt);
   XtAddCallback(makesel, XtNcallback, Make, NULL);

   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Run"); cnt++;
   runsel = XtCreateManagedWidget("runsel", smeBSBObjectClass,
				  parent, args, cnt);
   XtAddCallback(runsel, XtNcallback, Run, NULL);
   
   return;
}



/*
   FUNCTION: 		CreateHelpMenu

   Synopsis: 
       

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

static void
CreateHelpMenu(parent)

Widget
   parent;  /* The parent of this list of menu options */

{
   Arg
      args[MAXARGS];
   int
      cnt;
   Widget
      help1sel;
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel,    "Introduction"); cnt++;
   help1sel = XtCreateManagedWidget("help1sel", smeBSBObjectClass,
				    parent, args, cnt);

   XtAddCallback(help1sel, XtNcallback, XicaHelp, "gen2spec.hlp");

   return;
}



/*
  FUNCTION: 		CreateMenubar
  
  Synopsis: 
  Create the menubar for the interface.
  
  Initial purpose:
  Same as above.
  
  Present purpose:
  Same as above.
  
  Creator:	Conleth O'Connell
  Reviewer:	
  
  Modifications:
  DATE     WHO      REASON
  
  Globals used:
  none
  
  Globals Modified:
  none
  
  Return value:	void
  
  Range:		none
  */


Widget CreateMenubar(parent,horizw,vertw)

Widget
   parent,
   vertw,
   horizw;

{
   Widget
      menubar,
      filebut,
      filemenu,
      codemenu,
      codebut,
      helpbut,
      helpmenu;
   
   menubar = XtVaCreateManagedWidget( "menubar",
       groupWidgetClass, parent,
       XtNorientation, XtorientHorizontal,
       XtNspacing, 1,
       XtNmargin,  7,
       NULL );
   
   /*********** File menu **************/

   filebut = XtVaCreateManagedWidget( "File",
       menuButtonWidgetClass, menubar,
       XtNlabel,    "   File   ",
       XtNmenuName, "filemenu",
       XtNmargin,   0,
       NULL );
   
   filemenu = XtVaCreatePopupShell( "filemenu",
       simpleMenuWidgetClass, parent, 
       NULL );

   CreateFileMenu(filemenu);
   
   /*********** Code Generation **************/
   
   codebut = XtVaCreateManagedWidget( "Code",
       menuButtonWidgetClass, menubar,
       XtNlabel,    "   Code   ",
       XtNmenuName, "codemenu",
       XtNmargin,   0,
       NULL );
   
   codemenu = XtVaCreatePopupShell( "codemenu",
       simpleMenuWidgetClass, parent, 
       NULL );

   CreateCodeMenu(codemenu);
   
   /*********** Help **************/

   helpbut = XtVaCreateManagedWidget( "Help",
       menuButtonWidgetClass, menubar,
       XtNlabel,    "   Help   ",
       XtNmenuName, "helpmenu",
       XtNmargin,   0,
       NULL );
   
   helpmenu = XtVaCreatePopupShell( "helpmenu",
       simpleMenuWidgetClass, parent, 
       NULL );

   CreateHelpMenu(helpmenu);

   return(menubar);
}

==> ICA-1.6.tar.gz: ICA-1.6/src/MSI/Gen2Spec/menubar.c <==
/*
   Owner:       Copyright 1992 The Ohio State University,
                Integrated Chameleon Architecture
   Module:      menubar.c,v
   Purpose:     The menubar choices plus callbacks.

   Programmer:  Conleth O'Connell
   Reviewer:    
   Revision:    1.9
   Date:        1993/04/19 17:07:12

   HISTORY
   menubar.c,v
 * Revision 1.9  1993/04/19  17:07:12  ware
 * Merged John Boyds changes.
 *
 * Revision 1.8  92/05/29  16:20:30  boyd
 * Changes to improve resizing, consisting mostly of replacing Form widgets with
 * Group, Table, and Viewform.
 * 
 * 
 * Revision 1.7  92/03/18  16:08:42  ware
 * *** empty log message ***
 * 
 * Revision 1.6  92/03/16  12:20:31  ware
 * Merging cso and OSU versions.  Changes for titles.
 * 
 * Revision 1.5  1992/03/10  21:46:06  cso
 * Had to redo this b/c cvs lost it during commit.
 *
 * Revision 1.3  1992/02/21  23:02:39  cso
 * Removed spec2gen related routines
 *
 * Revision 1.2  1992/02/18  18:27:01  cso
 * Restructured the interface for the opposite xlation direction
 *
 * Revision 1.1  1992/02/06  05:33:52  cso
 * Initial revision
 *
 * Revision 1.2  1992/01/28  17:13:01  cso
 * Put border around menubar
 *
 * Revision 1.1  1992/01/08  19:55:30  cso
 * Initial revision
 *

   Functions Index:
   AVAIL   NAME DEPENDS ON INTERNALLY      EXTERNALLY
   -----   ----            ----------      ----------

*/

/* #INCLUDES */

#include "widgets.h"
#include "Xica/help.h"
#include "types.h"
#include "defs.h"

#include "interface.h"
#include "menucalls.h"



/*
   FUNCTION: 		CreateFileMenu

   Synopsis: 
       Create the file options.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/


static void
CreateFileMenu(parent)

Widget
   parent;  /* The parent of this list of menu options */

{
   Arg
      args[MAXARGS]; /* List of arguments */
   int
      cnt;      /* Number of arguments */
   Widget
      loadsel,  /* Load  option widget */
      newsel,   /* New   option widget */
      quitsel,  /* Quit  option widget */
      resetsel, /* Reset option widget */
      savesel;  /* Save  option widget */
   
   /*
    * Offer RESET first, a line to separate, LOAD and SAVE,
    * another line separator, and lastly QUIT
    */
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Reset    "); cnt++;
   resetsel = XtCreateManagedWidget("resetsel", smeBSBObjectClass,
				    parent, args, cnt);
   XtAddCallback(resetsel, XtNcallback, Reset, NULL);
   
   cnt = 0;
   XtSetArg(args[cnt], XtNlineWidth, 3); cnt++;
   (void) XtCreateManagedWidget("linesep", smeLineObjectClass,
				parent, args, cnt);
   
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "New      "); cnt++;
   newsel = XtCreateManagedWidget("newsel", smeBSBObjectClass,
				  parent, args, cnt);
   XtAddCallback(newsel, XtNcallback, FileLoad, (XtPointer) True);

   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Edit     "); cnt++;
   loadsel = XtCreateManagedWidget("loadsel", smeBSBObjectClass,
				   parent, args, cnt);
   XtAddCallback(loadsel, XtNcallback, FileLoad, (XtPointer) False);

   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Save     "); cnt++;
   savesel = XtCreateManagedWidget("savesel", smeBSBObjectClass,
				   parent, args, cnt);
   XtAddCallback(savesel, XtNcallback, FileSave, NULL);

   cnt = 0;
   XtSetArg(args[cnt], XtNlineWidth, 3); cnt++;
   (void) XtCreateManagedWidget("linesep", smeLineObjectClass,
				parent, args, cnt);
   
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Quit     "); cnt++;
   quitsel = XtCreateManagedWidget("quitsel", smeBSBObjectClass,
				   parent, args, cnt);
   XtAddCallback(quitsel, XtNcallback, Quit, NULL);

   return;
}



/*
   FUNCTION: 		CreateCodeMenu

   Synopsis: 
       The menu dealing with making and running.

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/


static void
CreateCodeMenu(parent)

Widget
   parent;  /* The parent of this list of menu options */

{
   Arg
      args[MAXARGS];
   int
      cnt;
   Widget
      makesel,
      runsel,
      shell;
   
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Make"); cnt++;
   makesel = XtCreateManagedWidget("makesel", smeBSBObjectClass,
				 parent, args, cnt);
   XtAddCallback(makesel, XtNcallback, Make, NULL);

   cnt = 0;
   XtSetArg(args[cnt], XtNlabel, "Run"); cnt++;
   runsel = XtCreateManagedWidget("runsel", smeBSBObjectClass,
				  parent, args, cnt);
   XtAddCallback(runsel, XtNcallback, Run, NULL);
   
   return;
}



/*
   FUNCTION: 		CreateHelpMenu

   Synopsis: 
       

   Initial purpose:
       Same as above.

   Present purpose:
       Same as above.

   Creator:	Conleth O'Connell
   Reviewer:	

   Modifications:
       DATE     WHO      REASON

   Globals used:
       none

   Globals Modified:
       none

   Return value:	void

   Range:		none
*/

static void
CreateHelpMenu(parent)

Widget
   parent;  /* The parent of this list of menu options */

{
   Arg
      args[MAXARGS];
   int
      cnt;
   Widget
      help1sel;
   cnt = 0;
   XtSetArg(args[cnt], XtNlabel,    "Introduction"); cnt++;
   help1sel = XtCreateManagedWidget("help1sel", smeBSBObjectClass,
				    parent, args, cnt);

   XtAddCallback(help1sel, XtNcallback, XicaHelp, "gen2spec.hlp");

   return;
}



/*
  FUNCTION: 		CreateMenubar
  
  Synopsis: 
  Create the menubar for the interface.
  
  Initial purpose:
  Same as above.
  
  Present purpose:
  Same as above.
  
  Creator:	Conleth O'Connell
  Reviewer:	
  
  Modifications:
  DATE     WHO      REASON
  
  Globals used:
  none
  
  Globals Modified:
  none
  
  Return value:	void
  
  Range:		none
  */


Widget CreateMenubar(parent,horizw,vertw)

Widget
   parent,
   vertw,
   horizw;

{
   Widget
      menubar,
      filebut,
      filemenu,
      codemenu,
      codebut,
      helpbut,
      helpmenu;
   
   menubar = XtVaCreateManagedWidget( "menubar",
       groupWidgetClass, parent,
       XtNorientation, XtorientHorizontal,
       XtNspacing, 1,
       XtNmargin,  7,
       NULL );
   
   /*********** File menu **************/

   filebut = XtVaCreateManagedWidget( "File",
       menuButtonWidgetClass, menubar,
       XtNlabel,    "   File   ",
       XtNmenuName, "filemenu",
       XtNmargin,   0,
       NULL );
   
   filemenu = XtVaCreatePopupShell( "filemenu",
       simpleMenuWidgetClass, parent, 
       NULL );

   CreateFileMenu(filemenu);
   
   /*********** Code Generation **************/
   
   codebut = XtVaCreateManagedWidget( "Code",
       menuButtonWidgetClass, menubar,
       XtNlabel,    "   Code   ",
       XtNmenuName, "codemenu",
       XtNmargin,   0,
       NULL );
   
   codemenu = XtVaCreatePopupShell( "codemenu",
       simpleMenuWidgetClass, parent, 
       NULL );

   CreateCodeMenu(codemenu);
   
   /*********** Help **************/

   helpbut = XtVaCreateManagedWidget( "Help",
       menuButtonWidgetClass, menubar,
       XtNlabel,    "   Help   ",
       XtNmenuName, "helpmenu",
       XtNmargin,   0,
       NULL );
   
   helpmenu = XtVaCreatePopupShell( "helpmenu",
       simpleMenuWidgetClass, parent, 
       NULL );

   CreateHelpMenu(helpmenu);

   return(menubar);
}
